==> apache-servicecomb-java-chassis-distribution-2.7.0-src.zip: apache-servicecomb-java-chassis-distribution-2.7.0-src/foundations/foundation-config/src/main/java/org/apache/servicecomb/config/spi/ConfigCenterConfigurationSourceLoader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.config.spi;

import java.util.List;

import org.apache.commons.configuration.Configuration;
import org.apache.servicecomb.foundation.common.utils.SPIServiceUtils;

public class ConfigCenterConfigurationSourceLoader {
  private static List<ConfigCenterConfigurationSource> configCenterConfigurationSources =
      SPIServiceUtils.getSortedService(ConfigCenterConfigurationSource.class);

  public static ConfigCenterConfigurationSource getConfigCenterConfigurationSource(Configuration localConfiguration) {

    ConfigCenterConfigurationSource configCenterConfigurationSource = null;

    for (ConfigCenterConfigurationSource item : configCenterConfigurationSources) {
      if (item.isValidSource(localConfiguration)) {
        configCenterConfigurationSource = item;
        break;
      }
    }

    return configCenterConfigurationSource;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.28-src.zip: apache-servicecomb-java-chassis-distribution-2.8.28-src/foundations/foundation-config/src/main/java/org/apache/servicecomb/config/spi/ConfigCenterConfigurationSourceLoader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.config.spi;

import java.util.List;

import org.apache.commons.configuration.Configuration;
import org.apache.servicecomb.foundation.common.utils.SPIServiceUtils;

public class ConfigCenterConfigurationSourceLoader {
  private static final List<ConfigCenterConfigurationSource> configCenterConfigurationSources =
      SPIServiceUtils.getSortedService(ConfigCenterConfigurationSource.class);

  public static ConfigCenterConfigurationSource getConfigCenterConfigurationSource(Configuration localConfiguration) {

    ConfigCenterConfigurationSource configCenterConfigurationSource = null;

    for (ConfigCenterConfigurationSource item : configCenterConfigurationSources) {
      if (item.isValidSource(localConfiguration)) {
        configCenterConfigurationSource = item;
        break;
      }
    }

    return configCenterConfigurationSource;
  }
}
